@@ -1,7 +1,9 @@
-( cd usr/lib ; rm -rf libstdc++.so.5 )
-( cd usr/lib ; ln -sf libstdc++.so.5.0.3 libstdc++.so.5 )
+( cd usr/lib ; rm -rf libstdc++.so.6 )
+( cd usr/lib ; ln -sf libstdc++.so.6.0.3 libstdc++.so.6 )
 ( cd usr/i486-slackware-linux/lib ; rm -rf libstdc++.so.4 )
 ( cd usr/i486-slackware-linux/lib ; ln -sf libstdc++.so.4.0.0 libstdc++.so.4 )
+( cd usr/i486-slackware-linux/lib ; rm -rf libstdc++.so.5 )
+( cd usr/i486-slackware-linux/lib ; ln -sf libstdc++.so.5.0.7 libstdc++.so.5 )
 ( cd usr/i486-slackware-linux/lib ; rm -rf libstdc++-libc6.2-2.so.3 )
 ( cd usr/i486-slackware-linux/lib ; ln -sf libstdc++-3-libc6.2-2-2.10.0.so libstdc++-libc6.2-2.so.3 )
 ( cd usr/i486-slackware-linux/lib ; rm -rf libstdc++.so.2.8 )
